use strict;
use warnings;
package {{ $name }};
# ABSTRACT: ...



1;
__END__

=pod

=head1 SYNOPSIS

    use $name;

    ...

=head1 DESCRIPTION

...

=head1 FUNCTIONS/METHODS

=over 4

=item * C<foo>

...

=back

=head1 SUPPORT

=for stopwords irc

Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name={{ $dist->name }}>
(or L<bug-{{ $dist->name }}@rt.cpan.org|mailto:bug-{{ $dist->name }}@rt.cpan.org>).
I am also usually active on irc, as 'ether' at C<irc.perl.org>.

=head1 ACKNOWLEDGEMENTS

...

=head1 SEE ALSO

=begin :list

* L<foo>

=end :list

=cut
